@@ -363,7 +363,7 @@ def silver_to_gold(input_table_name, data_pack_name, dataset_name, input_db_name
         apply_profiling(df=df, data_pack_name=data_pack_name, dataset_name=dataset_name)
 
 
-def gold_to_kafka(input_table_name, data_pack_name, dataset_name, topic_name, input_db_name=GOLD_DB_NAME, spark=None, write_options: dict = None,
+def gold_to_kafka(input_table_name, data_pack_name, dataset_name, topic_name, input_db_name=GOLD_DB_NAME, spark=None, write_options: dict = None, kafka_security_protocol='SSL',
                   kafka_bootstrap_servers=DEFAULT_BOOTSTRAP_SERVERS, processing_function=None, processing_function_args=None, processing_function_kwargs=None, reset_checkpoint=False):
     topics = [topic_name]
     create_topics_if_not_exists(topics=topics, bootstrap_servers=kafka_bootstrap_servers)
@@ -372,15 +372,19 @@ def gold_to_kafka(input_table_name, data_pack_name, dataset_name, topic_name, in
         spark = get_spark_session(app_name=dataset_name)
     if reset_checkpoint:
         __delete_checkpoint_location(bucket_name=GOLD_BUCKET, checkpoint_location=checkpoint_location)
+    if write_options is None:
+        write_options = dict()
 
     df = read_table(spark, db_name=input_db_name, table_name=input_table_name)
     df = apply_processing_function(df=df, func=processing_function, func_args=processing_function_args, func_kwargs=processing_function_kwargs)
 
-    stream = df.writeStream.trigger(once=True) \
+    stream = df.selectExpr("CAST(cortex_id AS STRING) as key", "to_json(struct(*)) AS value") \
+        .writeStream.trigger(once=True) \
         .format('kafka') \
         .option('checkpointLocation', checkpoint_location) \
         .option("kafka.bootstrap.servers", kafka_bootstrap_servers) \
         .option("topic", topic_name) \
+        .option("kafka.security.protocol", kafka_security_protocol) \
         .options(**write_options)
     stream.start()
 
